 /********************************************************************/
 /*                                                                  */
 /* Program name: DLQMON                                             */
 /*                                                                  */
 /* Description: C program that acts as a DLQ monitor                */
 /*                                                                  */
 /*                                                                  */
 /********************************************************************/
 /*                                                                  */
 /* Function:                                                        */
 /*                                                                  */
 /*   DLQMON is a C program that acts as a dead letter queue         */
 /*   monitor reads the dead letter queue and tells you if anything  */
 /*   appears on it. It leaves it there until you remove it.         */
 /*                                                                  */
 /*   It's second parameter is the queue manager name, the first is  */
 /*   the dead letter queue name. If these are not supplied it uses  */
 /*   the defaults.                                                  */
 /*   Status:          Version 1 Release 1 Modification 2            */
 /*   Date:            4 October 1995                                */
 /*   Author:          Sam Garforth (SJG Consulting Ltd)             */
 /*   Status:          Version 2 Release 1 Modification 0            */
 /*   Date:            7 November 2005                               */
 /*   Author:          Sam Garforth (SJG Consulting Ltd)             */
 /*    (sam.garforth@bigfoot.com, www.sjg-enterpriseintegration.com) */
 /*                                                                  */
 /********************************************************************/
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
 #include <stdio.h>

 #ifdef OS2
   /******************************************************************/
   /* for beep                                                       */
   /******************************************************************/
   #define INCL_DOSPROCESS
   #include <os2.h>
 #endif

 /********************************************************************/
 /* includes for MQI                                                 */
 /********************************************************************/
 #include <cmqc.h>
 #include <cmqcfc.h>

 /********************************************************************/
 /* prototype the functions                                          */
 /********************************************************************/
 void printreas(MQLONG reason);

 /********************************************************************/
 /* global variable                                                  */
 /********************************************************************/
 MQCFH    *dlqmsg;                    /* dlqmsg message buffer       */

 /********************************************************************/
 /* the program itself                                               */
 /********************************************************************/
 int main(int argc, char **argv)
 {
   /******************************************************************/
   /* Declare MQI structures needed                                  */
   /******************************************************************/
   MQOD     od = {MQOD_DEFAULT};      /* Object Descriptor           */
   MQMD     md = {MQMD_DEFAULT};      /* Message Descriptor          */
   MQGMO   gmo = {MQGMO_DEFAULT};     /* get message options         */
   /******************************************************************/
   /* note, uses defaults where it can                               */
   /******************************************************************/
   MQHCONN  Hcon;                      /* connection handle          */
   MQHOBJ   Hobj;                      /* object handle              */
   MQLONG   O_options;                 /* MQOPEN options             */
   MQLONG   C_options;                 /* MQCLOSE options            */
   MQLONG   CompCode;                  /* completion code            */
   MQLONG   OpenCode;                  /* MQOPEN completion code     */
   MQLONG   Reason;                    /* reason code                */
   MQLONG   CReason;                   /* reason code for MQCONN     */
   MQLONG   buflen;                    /* buffer length              */
   MQLONG   dlqmsglen;                 /* message length received    */
   char     QMName[50];                /* queue manager name         */
   time_t   ltime;                     /* for printing the time      */
   MQHOBJ  hobj;                       /* inquire Object handle      */
   MQOD    odenq       = { MQOD_DEFAULT };  /* Obj descr for enquire */
   MQLONG  opts;                       /* MQOPEN/MQCLOSE options     */
   MQLONG  selectcnt   =  1;           /* Count of inquire selectors */
   MQLONG  selectors[1];               /* Array of attr selectors    */
   MQLONG  intattrcnt  =  0;           /* Count of integer attrs     */
   MQLONG  intattr[1];                 /* Array of integer attrs     */

   /******************************************************************/
   /* union to help read the header                                  */
   /******************************************************************/
   union UDLH
   {
      MQDLH   mdlh;
      MQCHAR  cdlh[sizeof(MQDLH)];
   } dlh;

   /******************************************************************/
   /* See whether they want help                                     */
   /******************************************************************/
   if (argc > 1 && argv[1][0] == '?')
   {
     printf("Usage: dlqmon [DLQ] [QMgrName]\n" );
     exit(0);
   }

   /******************************************************************/
   /* Connect to queue manager                                       */
   /* If a queue manager name is specified then use it, otherwise    */
   /* use the default one                                            */
   /******************************************************************/
   QMName[0] = 0;                      /* default queue manager      */
   if (argc > 2)
     strcpy(QMName, argv[2]);
   MQCONN(QMName,                      /* queue manager              */
          &Hcon,                       /* connection handle          */
          &CompCode,                   /* completion code            */
          &CReason);                   /* reason code                */

   /******************************************************************/
   /* report reason and stop if it failed                            */
   /******************************************************************/
   if (CompCode == MQCC_FAILED)
   {
     printf("MQCONN ended with reason code %ld\n", CReason);
     printreas(CReason);
     exit(CReason);
   }

   /******************************************************************/
   /* Find the name of the dead letter queue                         */
   /******************************************************************/
   {
     /****************************************************************/
     /* Open the queue manager for inquire                           */
     /****************************************************************/
     odenq.ObjectType = MQOT_Q_MGR;
     strcpy(odenq.ObjectQMgrName,QMName);
     opts = MQOO_INQUIRE | MQOO_FAIL_IF_QUIESCING;

     MQOPEN(Hcon,&odenq,opts,&hobj,&CompCode,&Reason);

     /****************************************************************/
     /* if it failed then explain why and exit                       */
     /****************************************************************/
     if(CompCode == MQCC_FAILED)
     {
        printf("Unable to open queue manager (%s) for inquire\n",
                QMName);
        printreas(Reason);
        MQDISC(&Hcon,&CompCode,&Reason);
        exit(Reason);
     }
          
     /****************************************************************/
     /* Find out the name of the dead letter queue                   */
     /****************************************************************/
     selectors[0] = MQCA_DEAD_LETTER_Q_NAME;
     MQINQ(Hcon,hobj,selectcnt,selectors,intattrcnt,intattr,
            sizeof(od.ObjectName),od.ObjectName,&CompCode,&Reason);

     if(CompCode == MQCC_FAILED)
     {
        printf("Inquire failed to get dead letter queue name\n");
        printreas(Reason);
        MQCLOSE(Hcon,&hobj,MQCO_NONE,&CompCode,&Reason);
        MQDISC(&Hcon,&CompCode,&Reason);
        exit(Reason);
     }

     if (od.ObjectName[0] == ' ')
     {
        printf("There is no dead letter queue defined\n");
        MQCLOSE(Hcon,&hobj,MQCO_NONE,&CompCode,&Reason);
        MQDISC(&Hcon,&CompCode,&Reason);
        exit(Reason);
     }

     /****************************************************************/
     /* close the inquire queue                                      */
     /****************************************************************/
     C_options = 0;                  /* no close options             */
     MQCLOSE(Hcon,                   /* connection handle            */
            &hobj,                   /* object handle                */
            C_options,
            &CompCode,               /* completion code              */
            &Reason);                /* reason code                  */
     /****************************************************************/
     /* report reason it failed to close, if any                     */
     /****************************************************************/
     if (Reason != MQRC_NONE)
     {
       printf("MQCLOSE ==> %ld\n", Reason);
       printreas(Reason);
     }
   }

   /******************************************************************/
   /* just in case they really wanted to monitor a different queue   */
   /* we'll put this bit in                                          */
   /******************************************************************/
   if (argc > 1)
     strcpy(od.ObjectName, argv[1]);

   /******************************************************************/
   /* Open the event queue for input; exclusive or shared.  Use of   */
   /* the queue is controlled by the queue definition here           */
   /******************************************************************/
   O_options = MQOO_INPUT_AS_Q_DEF     /* open queue for input       */
         + MQOO_FAIL_IF_QUIESCING      /* but not if MQM stopping    */
         + MQOO_BROWSE;
   MQOPEN(Hcon,                        /* connection handle          */
          &od,                         /* object descriptor for queue*/
          O_options,                   /* open options               */
          &Hobj,                       /* object handle              */
          &CompCode,                   /* completion code            */
          &Reason);                    /* reason code                */

   /******************************************************************/
   /* report reason, if any; stop if failed                          */
   /******************************************************************/
   if (Reason != MQRC_NONE)
   {
     printf("MQOPEN (%s) ==> %ld\n", od.ObjectName, Reason);
     printreas(Reason);
   }

   OpenCode = CompCode;                /* keep for conditional close */

   /******************************************************************/
   /*   Get messages from the message queue                          */
   /******************************************************************/
   while (CompCode != MQCC_FAILED)
   {
     /****************************************************************/
     /* We don't know how big this message is so just get the        */
     /* descriptor first                                             */
     /* wait for new messages, and when we find one lock it so that  */
     /* we can get it when we've got the storage                     */
     /* We use convert just in case this is running as a client      */
     /****************************************************************/
     gmo.Options = MQGMO_WAIT + MQGMO_BROWSE_NEXT + MQGMO_LOCK
                      + MQGMO_ACCEPT_TRUNCATED_MSG + MQGMO_CONVERT;

     buflen = 0;                       /* ammount of message to get  */
     /****************************************************************/
     /* we used to have this as unlimited wait but we can't do       */
     /* this because if it's done from a client and the client dies  */
     /* then the server doesn't notice and keeps the queue open      */
     /* so now we loop on a 5 second wait                            */
     /****************************************************************/
     /*gmo.WaitInterval = MQWI_UNLIMITED;   no time limit            */
     gmo.WaitInterval = 5000;          /* 5 seconds                  */

     /****************************************************************/
     /* clear selectors to get messages in sequence                  */
     /****************************************************************/
     memcpy(md.MsgId, MQMI_NONE, sizeof(md.MsgId));
     memcpy(md.CorrelId, MQCI_NONE, sizeof(md.CorrelId));

     /****************************************************************/
     /* wait for event message                                       */
     /* if one doesn't arrive then wait again                        */
     /****************************************************************/
     printf("...>\n");
     for (Reason = MQRC_NO_MSG_AVAILABLE,
          CompCode = MQCC_FAILED;
          Reason == MQRC_NO_MSG_AVAILABLE
                && CompCode == MQCC_FAILED; )
     {
       MQGET(Hcon,                     /* connection handle          */
             Hobj,                     /* object handle              */
             &md,                      /* message descriptor         */
             &gmo,                     /* get message options        */
             buflen,                   /* buffer length              */
             dlqmsg,                   /* dlqmsg message buffer      */
             &dlqmsglen,               /* message length             */
             &CompCode,                /* completion code            */
             &Reason);                 /* reason code                */
     }

     /****************************************************************/
     /* report reason, if any                                        */
     /****************************************************************/
     if (Reason != MQRC_NONE && Reason != MQRC_TRUNCATED_MSG_ACCEPTED)
     {
       printf("MQGET ==> %ld\n", Reason);
       printreas(Reason);
     }
     else
     {
       gmo.Options = MQGMO_NO_WAIT + MQGMO_BROWSE_MSG_UNDER_CURSOR
                        + MQGMO_CONVERT;
       buflen = dlqmsglen;             /* ammount of message to get  */
       dlqmsg = malloc(buflen);
       if (dlqmsg != NULL)
       {
         /************************************************************/
         /* clear selectors to get messages in sequence              */
         /************************************************************/
         memcpy(md.MsgId, MQMI_NONE, sizeof(md.MsgId));
         memcpy(md.CorrelId, MQCI_NONE, sizeof(md.CorrelId));

         /************************************************************/
         /* get the message                                          */
         /************************************************************/
         printf("...>\n");
         MQGET(Hcon,                   /* connection handle          */
               Hobj,                   /* object handle              */
               &md,                    /* message descriptor         */
               &gmo,                   /* get message options        */
               buflen,                 /* buffer length              */
               dlqmsg,                 /* dlqmsg message buffer      */
               &dlqmsglen,             /* message length             */
               &CompCode,              /* completion code            */
               &Reason);               /* reason code                */

         /************************************************************/
         /* report reason, if any                                    */
         /************************************************************/
         if (Reason != MQRC_NONE)
         {
           printf("MQGET ==> %ld\n", Reason);
           printreas(Reason);
         }
       }
       else
       {
         CompCode = MQCC_FAILED;
       }
     }
     /****************************************************************/
     /* . . . process each message received                          */
     /****************************************************************/
     if (CompCode != MQCC_FAILED)
     {
       /**************************************************************/
       /* announce a message                                         */
       /**************************************************************/
       #ifdef OS2
         {
           unsigned short tone;
           for (tone = 1; tone < 8000; tone = tone * 2)
           {
             DosBeep(tone,25);
           }
         }
       #else
         printf("\a\a\a\a\a\a\a");
       #endif
       time(&ltime);
       printf(ctime(&ltime));

       /**************************************************************/
       /* if the data length is wrong then something has gone        */
       /* badly wrong as we've only just checked it before we got    */
       /* the storage                                                */
       /**************************************************************/
       if (dlqmsglen != buflen)
         printf("DataLength = %ld?\n", dlqmsglen);
       else
       {
         /************************************************************/
         /* right let's look at the data                             */
         /* make sure it's got a dead letter header on it and then   */
         /* read it                                                  */
         /************************************************************/
         if (!strncmp(((MQDLH*)dlqmsg)->StrucId,MQDLH_STRUC_ID,
               sizeof(((MQDLH*)dlqmsg)->StrucId)))
         {

           memcpy(dlh.cdlh,dlqmsg,sizeof(MQDLH));
           printf("PutDate = %8.8s PutTime = %8.8s Reason = %ld\n"
                  "DestQName = %.48s\nDestQMgrName = %.48s\n",
                  dlh.mdlh.PutDate,
                  dlh.mdlh.PutTime,
                  dlh.mdlh.Reason,
                  dlh.mdlh.DestQName,
                  dlh.mdlh.DestQMgrName);

           /**********************************************************/
           /* print the reason again, but decoded                    */
           /**********************************************************/
           printreas(dlh.mdlh.Reason);

         }
         else
         {
           printf("msg has no DLQ header\n");
         }
       }
       /**************************************************************/
       /* free the storage we obtained for the message               */
       /**************************************************************/
       free(dlqmsg);
     }                                 /* end process for GET        */
   }                                   /* end msg processing loop    */

   /******************************************************************/
   /* close the dead letter queue - if it was opened                 */
   /******************************************************************/
   if (OpenCode != MQCC_FAILED)
   {
     C_options = 0;                  /* no close options             */
     MQCLOSE(Hcon,                   /* connection handle            */
            &Hobj,                   /* object handle                */
            C_options,
            &CompCode,               /* completion code              */
            &Reason);                /* reason code                  */
     /****************************************************************/
     /* report reason, if any                                        */
     /****************************************************************/
     if (Reason != MQRC_NONE)
     {
       printf("MQCLOSE ==> %ld\n", Reason);
       printreas(Reason);       
     }
   }

   /******************************************************************/
   /* Disconnect from MQM  (unless previously connected)             */
   /******************************************************************/
   if (CReason != MQRC_ALREADY_CONNECTED)
   {
     MQDISC(&Hcon,                   /* connection handle            */
            &CompCode,               /* completion code              */
            &Reason);                /* reason code                  */
     /****************************************************************/
     /* report reason, if any                                        */
     /****************************************************************/
     if (Reason != MQRC_NONE)
     {
       printf("MQDISC ended with reason code %ld\n", Reason);
     }
   }
   return 0;
 /********************************************************************/
 /*                                                                  */
 /* END OF DLQMON                                                    */
 /*                                                                  */
 /********************************************************************/
 }

/*********************************************************************/
/* define macros                                                     */
/*********************************************************************/
 #define PRINTREAS(param)                                            \
    case param:                                                      \
      printf("Reason = %s\n",#param);                                \
      break;

void printreas(MQLONG reason)
{
  switch (reason)
  {
    PRINTREAS(MQRCCF_CFH_TYPE_ERROR             )
    PRINTREAS(MQRCCF_CFH_LENGTH_ERROR           )
    PRINTREAS(MQRCCF_CFH_VERSION_ERROR          )
    PRINTREAS(MQRCCF_CFH_MSG_SEQ_NUMBER_ERR     )
    PRINTREAS(MQRCCF_CFH_CONTROL_ERROR          )
    PRINTREAS(MQRCCF_CFH_PARM_COUNT_ERROR       )
    PRINTREAS(MQRCCF_CFH_COMMAND_ERROR          )
    PRINTREAS(MQRCCF_COMMAND_FAILED             )
    PRINTREAS(MQRCCF_CFIN_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFST_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFST_STRING_LENGTH_ERR     )
    PRINTREAS(MQRCCF_FORCE_VALUE_ERROR          )
    PRINTREAS(MQRCCF_STRUCTURE_TYPE_ERROR       )
    PRINTREAS(MQRCCF_CFIN_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFST_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_MSG_LENGTH_ERROR           )
    PRINTREAS(MQRCCF_CFIN_DUPLICATE_PARM        )
    PRINTREAS(MQRCCF_CFST_DUPLICATE_PARM        )
    PRINTREAS(MQRCCF_PARM_COUNT_TOO_SMALL       )
    PRINTREAS(MQRCCF_PARM_COUNT_TOO_BIG         )
    PRINTREAS(MQRCCF_Q_ALREADY_IN_CELL          )
    PRINTREAS(MQRCCF_Q_TYPE_ERROR               )
    PRINTREAS(MQRCCF_MD_FORMAT_ERROR            )
    PRINTREAS(MQRCCF_CFSL_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_REPLACE_VALUE_ERROR        )
    PRINTREAS(MQRCCF_CFIL_DUPLICATE_VALUE       )
    PRINTREAS(MQRCCF_CFIL_COUNT_ERROR           )
    PRINTREAS(MQRCCF_CFIL_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_MODE_VALUE_ERROR           )
    PRINTREAS(MQRCCF_MSG_SEQ_NUMBER_ERROR       )
    PRINTREAS(MQRCCF_PING_DATA_COUNT_ERROR      )
    PRINTREAS(MQRCCF_PING_DATA_COMPARE_ERROR    )
    PRINTREAS(MQRCCF_CFSL_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CHANNEL_TYPE_ERROR         )
    PRINTREAS(MQRCCF_PARM_SEQUENCE_ERROR        )
    PRINTREAS(MQRCCF_XMIT_PROTOCOL_TYPE_ERR     )
    PRINTREAS(MQRCCF_BATCH_SIZE_ERROR           )
    PRINTREAS(MQRCCF_DISC_INT_ERROR             )
    PRINTREAS(MQRCCF_SHORT_RETRY_ERROR          )
    PRINTREAS(MQRCCF_SHORT_TIMER_ERROR          )
    PRINTREAS(MQRCCF_LONG_RETRY_ERROR           )
    PRINTREAS(MQRCCF_LONG_TIMER_ERROR           )
    PRINTREAS(MQRCCF_SEQ_NUMBER_WRAP_ERROR      )
    PRINTREAS(MQRCCF_MAX_MSG_LENGTH_ERROR       )
    PRINTREAS(MQRCCF_PUT_AUTH_ERROR             )
    PRINTREAS(MQRCCF_PURGE_VALUE_ERROR          )
    PRINTREAS(MQRCCF_CFIL_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_MSG_TRUNCATED              )
    PRINTREAS(MQRCCF_CCSID_ERROR                )
    PRINTREAS(MQRCCF_ENCODING_ERROR             )
    PRINTREAS(MQRCCF_QUEUES_VALUE_ERROR         )
    PRINTREAS(MQRCCF_DATA_CONV_VALUE_ERROR      )
    PRINTREAS(MQRCCF_INDOUBT_VALUE_ERROR        )
    PRINTREAS(MQRCCF_ESCAPE_TYPE_ERROR          )
    PRINTREAS(MQRCCF_REPOS_VALUE_ERROR          )
    PRINTREAS(MQRCCF_CHANNEL_TABLE_ERROR        )
    PRINTREAS(MQRCCF_MCA_TYPE_ERROR             )
    PRINTREAS(MQRCCF_CHL_INST_TYPE_ERROR        )
    PRINTREAS(MQRCCF_CHL_STATUS_NOT_FOUND       )
    PRINTREAS(MQRCCF_CFSL_DUPLICATE_PARM        )
    PRINTREAS(MQRCCF_CFSL_TOTAL_LENGTH_ERROR    )
    PRINTREAS(MQRCCF_CFSL_COUNT_ERROR           )
    PRINTREAS(MQRCCF_CFSL_STRING_LENGTH_ERR     )
    PRINTREAS(MQRCCF_BROKER_DELETED             )
    PRINTREAS(MQRCCF_STREAM_ERROR               )
    PRINTREAS(MQRCCF_TOPIC_ERROR                )
    PRINTREAS(MQRCCF_NOT_REGISTERED             )
    PRINTREAS(MQRCCF_Q_MGR_NAME_ERROR           )
    PRINTREAS(MQRCCF_INCORRECT_STREAM           )
    PRINTREAS(MQRCCF_Q_NAME_ERROR               )
    PRINTREAS(MQRCCF_NO_RETAINED_MSG            )
    PRINTREAS(MQRCCF_DUPLICATE_IDENTITY         )
    PRINTREAS(MQRCCF_INCORRECT_Q                )
    PRINTREAS(MQRCCF_CORREL_ID_ERROR            )
    PRINTREAS(MQRCCF_NOT_AUTHORIZED             )
    PRINTREAS(MQRCCF_UNKNOWN_STREAM             )
    PRINTREAS(MQRCCF_REG_OPTIONS_ERROR          )
    PRINTREAS(MQRCCF_PUB_OPTIONS_ERROR          )
    PRINTREAS(MQRCCF_UNKNOWN_BROKER             )
    PRINTREAS(MQRCCF_Q_MGR_CCSID_ERROR          )
    PRINTREAS(MQRCCF_DEL_OPTIONS_ERROR          )
    PRINTREAS(MQRCCF_CLUSTER_NAME_CONFLICT      )
    PRINTREAS(MQRCCF_REPOS_NAME_CONFLICT        )
    PRINTREAS(MQRCCF_CLUSTER_Q_USAGE_ERROR      )
    PRINTREAS(MQRCCF_ACTION_VALUE_ERROR         )
    PRINTREAS(MQRCCF_COMMS_LIBRARY_ERROR        )
    PRINTREAS(MQRCCF_NETBIOS_NAME_ERROR         )
    PRINTREAS(MQRCCF_BROKER_COMMAND_FAILED      )
    PRINTREAS(MQRCCF_CFST_CONFLICTING_PARM      )
    PRINTREAS(MQRCCF_PATH_NOT_VALID             )
    PRINTREAS(MQRCCF_PARM_SYNTAX_ERROR          )
    PRINTREAS(MQRCCF_PWD_LENGTH_ERROR           )
    PRINTREAS(MQRCCF_FILTER_ERROR               )
    PRINTREAS(MQRCCF_WRONG_USER                 )
    PRINTREAS(MQRCCF_DUPLICATE_SUBSCRIPTION     )
    PRINTREAS(MQRCCF_SUB_NAME_ERROR             )
    PRINTREAS(MQRCCF_SUB_IDENTITY_ERROR         )
    PRINTREAS(MQRCCF_SUBSCRIPTION_IN_USE        )
    PRINTREAS(MQRCCF_SUBSCRIPTION_LOCKED        )
    PRINTREAS(MQRCCF_ALREADY_JOINED             )
    PRINTREAS(MQRCCF_OBJECT_IN_USE              )
    PRINTREAS(MQRCCF_UNKNOWN_FILE_NAME          )
    PRINTREAS(MQRCCF_FILE_NOT_AVAILABLE         )
    PRINTREAS(MQRCCF_DISC_RETRY_ERROR           )
    PRINTREAS(MQRCCF_ALLOC_RETRY_ERROR          )
    PRINTREAS(MQRCCF_ALLOC_SLOW_TIMER_ERROR     )
    PRINTREAS(MQRCCF_ALLOC_FAST_TIMER_ERROR     )
    PRINTREAS(MQRCCF_PORT_NUMBER_ERROR          )
    PRINTREAS(MQRCCF_CHL_SYSTEM_NOT_ACTIVE      )
    PRINTREAS(MQRCCF_ENTITY_NAME_MISSING        )
    PRINTREAS(MQRCCF_PROFILE_NAME_ERROR         )
    PRINTREAS(MQRCCF_AUTH_VALUE_ERROR           )
    PRINTREAS(MQRCCF_AUTH_VALUE_MISSING         )
    PRINTREAS(MQRCCF_OBJECT_TYPE_MISSING        )
    PRINTREAS(MQRCCF_CONNECTION_ID_ERROR        )
    PRINTREAS(MQRCCF_LOG_TYPE_ERROR             )
    PRINTREAS(MQRCCF_PROGRAM_NOT_AVAILABLE      )
    PRINTREAS(MQRCCF_PROGRAM_AUTH_FAILED        )
    PRINTREAS(MQRCCF_NONE_FOUND                 )
    PRINTREAS(MQRCCF_SECURITY_SWITCH_OFF        )
    PRINTREAS(MQRCCF_SECURITY_REFRESH_FAILED    )
    PRINTREAS(MQRCCF_PARM_CONFLICT              )
    PRINTREAS(MQRCCF_COMMAND_INHIBITED          )
    PRINTREAS(MQRCCF_OBJECT_BEING_DELETED       )
    PRINTREAS(MQRCCF_STORAGE_CLASS_IN_USE       )
    PRINTREAS(MQRCCF_OBJECT_NAME_RESTRICTED     )
    PRINTREAS(MQRCCF_OBJECT_LIMIT_EXCEEDED      )
    PRINTREAS(MQRCCF_OBJECT_OPEN_FORCE          )
    PRINTREAS(MQRCCF_DISPOSITION_CONFLICT       )
    PRINTREAS(MQRCCF_Q_MGR_NOT_IN_QSG           )
    PRINTREAS(MQRCCF_ATTR_VALUE_FIXED           )
    PRINTREAS(MQRCCF_NAMELIST_ERROR             )
    PRINTREAS(MQRCCF_NO_CHANNEL_INITIATOR       )
    PRINTREAS(MQRCCF_CHANNEL_INITIATOR_ERROR    )
    PRINTREAS(MQRCCF_COMMAND_LEVEL_CONFLICT     )
    PRINTREAS(MQRCCF_Q_ATTR_CONFLICT            )
    PRINTREAS(MQRCCF_EVENTS_DISABLED            )
    PRINTREAS(MQRCCF_COMMAND_SCOPE_ERROR        )
    PRINTREAS(MQRCCF_COMMAND_REPLY_ERROR        )
    PRINTREAS(MQRCCF_FUNCTION_RESTRICTED        )
    PRINTREAS(MQRCCF_PARM_MISSING               )
    PRINTREAS(MQRCCF_PARM_VALUE_ERROR           )
    PRINTREAS(MQRCCF_COMMAND_LENGTH_ERROR       )
    PRINTREAS(MQRCCF_COMMAND_ORIGIN_ERROR       )
    PRINTREAS(MQRCCF_LISTENER_CONFLICT          )
    PRINTREAS(MQRCCF_LISTENER_STARTED           )
    PRINTREAS(MQRCCF_LISTENER_STOPPED           )
    PRINTREAS(MQRCCF_CHANNEL_ERROR              )
    PRINTREAS(MQRCCF_CF_STRUC_ERROR             )
    PRINTREAS(MQRCCF_UNKNOWN_USER_ID            )
    PRINTREAS(MQRCCF_UNEXPECTED_ERROR           )
    PRINTREAS(MQRCCF_NO_XCF_PARTNER             )
    PRINTREAS(MQRCCF_CFGR_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFIF_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFIF_OPERATOR_ERROR        )
    PRINTREAS(MQRCCF_CFIF_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFSF_FILTER_VAL_LEN_ERR    )
    PRINTREAS(MQRCCF_CFSF_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFSF_OPERATOR_ERROR        )
    PRINTREAS(MQRCCF_CFSF_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_TOO_MANY_FILTERS           )
    PRINTREAS(MQRCCF_LISTENER_RUNNING           )
    PRINTREAS(MQRCCF_LSTR_STATUS_NOT_FOUND      )
    PRINTREAS(MQRCCF_SERVICE_RUNNING            )
    PRINTREAS(MQRCCF_SERV_STATUS_NOT_FOUND      )
    PRINTREAS(MQRCCF_SERVICE_STOPPED            )
    PRINTREAS(MQRCCF_CFBS_DUPLICATE_PARM        )
    PRINTREAS(MQRCCF_CFBS_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFBS_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFBS_STRING_LENGTH_ERR     )
    PRINTREAS(MQRCCF_CFGR_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFGR_PARM_COUNT_ERROR      )
    PRINTREAS(MQRCCF_CONN_NOT_STOPPED           )
    PRINTREAS(MQRCCF_SERVICE_REQUEST_PENDING    )
    PRINTREAS(MQRCCF_NO_START_CMD               )
    PRINTREAS(MQRCCF_NO_STOP_CMD                )
    PRINTREAS(MQRCCF_CFBF_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFBF_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFBF_OPERATOR_ERROR        )
    PRINTREAS(MQRCCF_CFBF_FILTER_VAL_LEN_ERR    )
    PRINTREAS(MQRCCF_LISTENER_STILL_ACTIVE      )
    PRINTREAS(MQRCCF_OBJECT_ALREADY_EXISTS      )
    PRINTREAS(MQRCCF_OBJECT_WRONG_TYPE          )
    PRINTREAS(MQRCCF_LIKE_OBJECT_WRONG_TYPE     )
    PRINTREAS(MQRCCF_OBJECT_OPEN                )
    PRINTREAS(MQRCCF_ATTR_VALUE_ERROR           )
    PRINTREAS(MQRCCF_UNKNOWN_Q_MGR              )
    PRINTREAS(MQRCCF_Q_WRONG_TYPE               )
    PRINTREAS(MQRCCF_OBJECT_NAME_ERROR          )
    PRINTREAS(MQRCCF_ALLOCATE_FAILED            )
    PRINTREAS(MQRCCF_HOST_NOT_AVAILABLE         )
    PRINTREAS(MQRCCF_CONFIGURATION_ERROR        )
    PRINTREAS(MQRCCF_CONNECTION_REFUSED         )
    PRINTREAS(MQRCCF_ENTRY_ERROR                )
    PRINTREAS(MQRCCF_SEND_FAILED                )
    PRINTREAS(MQRCCF_RECEIVED_DATA_ERROR        )
    PRINTREAS(MQRCCF_RECEIVE_FAILED             )
    PRINTREAS(MQRCCF_CONNECTION_CLOSED          )
    PRINTREAS(MQRCCF_NO_STORAGE                 )
    PRINTREAS(MQRCCF_NO_COMMS_MANAGER           )
    PRINTREAS(MQRCCF_LISTENER_NOT_STARTED       )
    PRINTREAS(MQRCCF_BIND_FAILED                )
    PRINTREAS(MQRCCF_CHANNEL_INDOUBT            )
    PRINTREAS(MQRCCF_MQCONN_FAILED              )
    PRINTREAS(MQRCCF_MQOPEN_FAILED              )
    PRINTREAS(MQRCCF_MQGET_FAILED               )
    PRINTREAS(MQRCCF_MQPUT_FAILED               )
    PRINTREAS(MQRCCF_PING_ERROR                 )
    PRINTREAS(MQRCCF_CHANNEL_IN_USE             )
    PRINTREAS(MQRCCF_CHANNEL_NOT_FOUND          )
    PRINTREAS(MQRCCF_UNKNOWN_REMOTE_CHANNEL     )
    PRINTREAS(MQRCCF_REMOTE_QM_UNAVAILABLE      )
    PRINTREAS(MQRCCF_REMOTE_QM_TERMINATING      )
    PRINTREAS(MQRCCF_MQINQ_FAILED               )
    PRINTREAS(MQRCCF_NOT_XMIT_Q                 )
    PRINTREAS(MQRCCF_CHANNEL_DISABLED           )
    PRINTREAS(MQRCCF_USER_EXIT_NOT_AVAILABLE    )
    PRINTREAS(MQRCCF_COMMIT_FAILED              )
    PRINTREAS(MQRCCF_WRONG_CHANNEL_TYPE         )
    PRINTREAS(MQRCCF_CHANNEL_ALREADY_EXISTS     )
    PRINTREAS(MQRCCF_DATA_TOO_LARGE             )
    PRINTREAS(MQRCCF_CHANNEL_NAME_ERROR         )
    PRINTREAS(MQRCCF_XMIT_Q_NAME_ERROR          )
    PRINTREAS(MQRCCF_MCA_NAME_ERROR             )
    PRINTREAS(MQRCCF_SEND_EXIT_NAME_ERROR       )
    PRINTREAS(MQRCCF_SEC_EXIT_NAME_ERROR        )
    PRINTREAS(MQRCCF_MSG_EXIT_NAME_ERROR        )
    PRINTREAS(MQRCCF_RCV_EXIT_NAME_ERROR        )
    PRINTREAS(MQRCCF_XMIT_Q_NAME_WRONG_TYPE     )
    PRINTREAS(MQRCCF_MCA_NAME_WRONG_TYPE        )
    PRINTREAS(MQRCCF_DISC_INT_WRONG_TYPE        )
    PRINTREAS(MQRCCF_SHORT_RETRY_WRONG_TYPE     )
    PRINTREAS(MQRCCF_SHORT_TIMER_WRONG_TYPE     )
    PRINTREAS(MQRCCF_LONG_RETRY_WRONG_TYPE      )
    PRINTREAS(MQRCCF_LONG_TIMER_WRONG_TYPE      )
    PRINTREAS(MQRCCF_PUT_AUTH_WRONG_TYPE        )
    PRINTREAS(MQRCCF_KEEP_ALIVE_INT_ERROR       )
    PRINTREAS(MQRCCF_MISSING_CONN_NAME          )
    PRINTREAS(MQRCCF_CONN_NAME_ERROR            )
    PRINTREAS(MQRCCF_MQSET_FAILED               )
    PRINTREAS(MQRCCF_CHANNEL_NOT_ACTIVE         )
    PRINTREAS(MQRCCF_TERMINATED_BY_SEC_EXIT     )
    PRINTREAS(MQRCCF_DYNAMIC_Q_SCOPE_ERROR      )
    PRINTREAS(MQRCCF_CELL_DIR_NOT_AVAILABLE     )
    PRINTREAS(MQRCCF_MR_COUNT_ERROR             )
    PRINTREAS(MQRCCF_MR_COUNT_WRONG_TYPE        )
    PRINTREAS(MQRCCF_MR_EXIT_NAME_ERROR         )
    PRINTREAS(MQRCCF_MR_EXIT_NAME_WRONG_TYPE    )
    PRINTREAS(MQRCCF_MR_INTERVAL_ERROR          )
    PRINTREAS(MQRCCF_MR_INTERVAL_WRONG_TYPE     )
    PRINTREAS(MQRCCF_NPM_SPEED_ERROR            )
    PRINTREAS(MQRCCF_NPM_SPEED_WRONG_TYPE       )
    PRINTREAS(MQRCCF_HB_INTERVAL_ERROR          )
    PRINTREAS(MQRCCF_HB_INTERVAL_WRONG_TYPE     )
    PRINTREAS(MQRCCF_CHAD_ERROR                 )
    PRINTREAS(MQRCCF_CHAD_WRONG_TYPE            )
    PRINTREAS(MQRCCF_CHAD_EVENT_ERROR           )
    PRINTREAS(MQRCCF_CHAD_EVENT_WRONG_TYPE      )
    PRINTREAS(MQRCCF_CHAD_EXIT_ERROR            )
    PRINTREAS(MQRCCF_CHAD_EXIT_WRONG_TYPE       )
    PRINTREAS(MQRCCF_SUPPRESSED_BY_EXIT         )
    PRINTREAS(MQRCCF_BATCH_INT_ERROR            )
    PRINTREAS(MQRCCF_BATCH_INT_WRONG_TYPE       )
    PRINTREAS(MQRCCF_NET_PRIORITY_ERROR         )
    PRINTREAS(MQRCCF_NET_PRIORITY_WRONG_TYPE    )
    PRINTREAS(MQRCCF_CHANNEL_CLOSED             )
    PRINTREAS(MQRCCF_Q_STATUS_NOT_FOUND         )
    PRINTREAS(MQRCCF_SSL_CIPHER_SPEC_ERROR      )
    PRINTREAS(MQRCCF_SSL_PEER_NAME_ERROR        )
    PRINTREAS(MQRCCF_SSL_CLIENT_AUTH_ERROR      )
    PRINTREAS(MQRCCF_RETAINED_NOT_SUPPORTED     )
    PRINTREAS(MQRC_NONE                      )
    PRINTREAS(MQRC_ALIAS_BASE_Q_TYPE_ERROR   )
    PRINTREAS(MQRC_ALREADY_CONNECTED         )
    PRINTREAS(MQRC_BACKED_OUT                )
    PRINTREAS(MQRC_BUFFER_ERROR              )
    PRINTREAS(MQRC_BUFFER_LENGTH_ERROR       )
    PRINTREAS(MQRC_CHAR_ATTR_LENGTH_ERROR    )
    PRINTREAS(MQRC_CHAR_ATTRS_ERROR          )
    PRINTREAS(MQRC_CHAR_ATTRS_TOO_SHORT      )
    PRINTREAS(MQRC_CONNECTION_BROKEN         )
    PRINTREAS(MQRC_DATA_LENGTH_ERROR         )
    PRINTREAS(MQRC_DYNAMIC_Q_NAME_ERROR      )
    PRINTREAS(MQRC_ENVIRONMENT_ERROR         )
    PRINTREAS(MQRC_EXPIRY_ERROR              )
    PRINTREAS(MQRC_FEEDBACK_ERROR            )
    PRINTREAS(MQRC_GET_INHIBITED             )
    PRINTREAS(MQRC_HANDLE_NOT_AVAILABLE      )
    PRINTREAS(MQRC_HCONN_ERROR               )
    PRINTREAS(MQRC_HOBJ_ERROR                )
    PRINTREAS(MQRC_INHIBIT_VALUE_ERROR       )
    PRINTREAS(MQRC_INT_ATTR_COUNT_ERROR      )
    PRINTREAS(MQRC_INT_ATTR_COUNT_TOO_SMALL  )
    PRINTREAS(MQRC_INT_ATTRS_ARRAY_ERROR     )
    PRINTREAS(MQRC_SYNCPOINT_LIMIT_REACHED   )
    PRINTREAS(MQRC_MAX_CONNS_LIMIT_REACHED   )
    PRINTREAS(MQRC_MD_ERROR                  )
    PRINTREAS(MQRC_MISSING_REPLY_TO_Q        )
    PRINTREAS(MQRC_MSG_TYPE_ERROR            )
    PRINTREAS(MQRC_MSG_TOO_BIG_FOR_Q         )
    PRINTREAS(MQRC_MSG_TOO_BIG_FOR_Q_MGR     )
    PRINTREAS(MQRC_NO_MSG_AVAILABLE          )
    PRINTREAS(MQRC_NO_MSG_UNDER_CURSOR       )
    PRINTREAS(MQRC_NOT_AUTHORIZED            )
    PRINTREAS(MQRC_NOT_OPEN_FOR_BROWSE       )
    PRINTREAS(MQRC_NOT_OPEN_FOR_INPUT        )
    PRINTREAS(MQRC_NOT_OPEN_FOR_INQUIRE      )
    PRINTREAS(MQRC_NOT_OPEN_FOR_OUTPUT       )
    PRINTREAS(MQRC_NOT_OPEN_FOR_SET          )
    PRINTREAS(MQRC_OBJECT_CHANGED            )
    PRINTREAS(MQRC_OBJECT_IN_USE             )
    PRINTREAS(MQRC_OBJECT_TYPE_ERROR         )
    PRINTREAS(MQRC_OD_ERROR                  )
    PRINTREAS(MQRC_OPTION_NOT_VALID_FOR_TYPE )
    PRINTREAS(MQRC_OPTIONS_ERROR             )
    PRINTREAS(MQRC_PERSISTENCE_ERROR         )
    PRINTREAS(MQRC_PERSISTENT_NOT_ALLOWED    )
    PRINTREAS(MQRC_PRIORITY_EXCEEDS_MAXIMUM  )
    PRINTREAS(MQRC_PRIORITY_ERROR            )
    PRINTREAS(MQRC_PUT_INHIBITED             )
    PRINTREAS(MQRC_Q_DELETED                 )
    PRINTREAS(MQRC_Q_FULL                    )
    PRINTREAS(MQRC_Q_NOT_EMPTY               )
    PRINTREAS(MQRC_Q_SPACE_NOT_AVAILABLE     )
    PRINTREAS(MQRC_Q_TYPE_ERROR              )
    PRINTREAS(MQRC_Q_MGR_NAME_ERROR          )
    PRINTREAS(MQRC_Q_MGR_NOT_AVAILABLE       )
    PRINTREAS(MQRC_REPORT_OPTIONS_ERROR      )
    PRINTREAS(MQRC_SECOND_MARK_NOT_ALLOWED   )
    PRINTREAS(MQRC_SECURITY_ERROR            )
    PRINTREAS(MQRC_SELECTOR_COUNT_ERROR      )
    PRINTREAS(MQRC_SELECTOR_LIMIT_EXCEEDED   )
    PRINTREAS(MQRC_SELECTOR_ERROR            )
    PRINTREAS(MQRC_SELECTOR_NOT_FOR_TYPE     )
    PRINTREAS(MQRC_SIGNAL_OUTSTANDING        )
    PRINTREAS(MQRC_SIGNAL_REQUEST_ACCEPTED   )
    PRINTREAS(MQRC_STORAGE_NOT_AVAILABLE     )
    PRINTREAS(MQRC_SYNCPOINT_NOT_AVAILABLE   )
    PRINTREAS(MQRC_TRIGGER_CONTROL_ERROR     )
    PRINTREAS(MQRC_TRIGGER_DEPTH_ERROR       )
    PRINTREAS(MQRC_TRIGGER_MSG_PRIORITY_ERR  )
    PRINTREAS(MQRC_TRIGGER_TYPE_ERROR        )
    PRINTREAS(MQRC_TRUNCATED_MSG_ACCEPTED    )
    PRINTREAS(MQRC_TRUNCATED_MSG_FAILED      )
    PRINTREAS(MQRC_UNKNOWN_ALIAS_BASE_Q      )
    PRINTREAS(MQRC_UNKNOWN_OBJECT_NAME       )
    PRINTREAS(MQRC_UNKNOWN_OBJECT_Q_MGR      )
    PRINTREAS(MQRC_UNKNOWN_REMOTE_Q_MGR      )
    PRINTREAS(MQRC_WAIT_INTERVAL_ERROR       )
    PRINTREAS(MQRC_XMIT_Q_TYPE_ERROR         )
    PRINTREAS(MQRC_XMIT_Q_USAGE_ERROR        )
    PRINTREAS(MQRC_NOT_OPEN_FOR_PASS_ALL     )
    PRINTREAS(MQRC_NOT_OPEN_FOR_PASS_IDENT   )
    PRINTREAS(MQRC_NOT_OPEN_FOR_SET_ALL      )
    PRINTREAS(MQRC_NOT_OPEN_FOR_SET_IDENT    )
    PRINTREAS(MQRC_CONTEXT_HANDLE_ERROR      )
    PRINTREAS(MQRC_CONTEXT_NOT_AVAILABLE     )
    PRINTREAS(MQRC_SIGNAL1_ERROR             )
    PRINTREAS(MQRC_OBJECT_ALREADY_EXISTS     )
    PRINTREAS(MQRC_OBJECT_DAMAGED            )
    PRINTREAS(MQRC_RESOURCE_PROBLEM          )
    PRINTREAS(MQRC_ANOTHER_Q_MGR_CONNECTED   )
    PRINTREAS(MQRC_UNKNOWN_REPORT_OPTION     )
    PRINTREAS(MQRC_STORAGE_CLASS_ERROR       )
    PRINTREAS(MQRC_COD_NOT_VALID_FOR_XCF_Q   )
    PRINTREAS(MQRC_XWAIT_CANCELED            )
    PRINTREAS(MQRC_XWAIT_ERROR               )
    PRINTREAS(MQRC_SUPPRESSED_BY_EXIT        )
    PRINTREAS(MQRC_FORMAT_ERROR              )
    PRINTREAS(MQRC_SOURCE_CCSID_ERROR        )
    PRINTREAS(MQRC_SOURCE_INTEGER_ENC_ERROR  )
    PRINTREAS(MQRC_SOURCE_DECIMAL_ENC_ERROR  )
    PRINTREAS(MQRC_SOURCE_FLOAT_ENC_ERROR    )
    PRINTREAS(MQRC_TARGET_CCSID_ERROR        )
    PRINTREAS(MQRC_TARGET_INTEGER_ENC_ERROR  )
    PRINTREAS(MQRC_TARGET_DECIMAL_ENC_ERROR  )
    PRINTREAS(MQRC_TARGET_FLOAT_ENC_ERROR    )
    PRINTREAS(MQRC_NOT_CONVERTED             )
    PRINTREAS(MQRC_CONVERTED_MSG_TOO_BIG     )
    PRINTREAS(MQRC_NO_EXTERNAL_PARTICIPANTS  )
    PRINTREAS(MQRC_PARTICIPANT_NOT_AVAILABLE )
    PRINTREAS(MQRC_OUTCOME_MIXED             )
    PRINTREAS(MQRC_OUTCOME_PENDING           )
    PRINTREAS(MQRC_BRIDGE_STARTED            )
    PRINTREAS(MQRC_BRIDGE_STOPPED            )
    PRINTREAS(MQRC_ADAPTER_STORAGE_SHORTAGE  )
    PRINTREAS(MQRC_UOW_IN_PROGRESS           )
    PRINTREAS(MQRC_ADAPTER_CONN_LOAD_ERROR   )
    PRINTREAS(MQRC_ADAPTER_SERV_LOAD_ERROR   )
    PRINTREAS(MQRC_ADAPTER_DEFS_ERROR        )
    PRINTREAS(MQRC_ADAPTER_DEFS_LOAD_ERROR   )
    PRINTREAS(MQRC_ADAPTER_CONV_LOAD_ERROR   )
    PRINTREAS(MQRC_BO_ERROR                  )
    PRINTREAS(MQRC_DH_ERROR                  )
    PRINTREAS(MQRC_MULTIPLE_REASONS          )
    PRINTREAS(MQRC_OPEN_FAILED               )
    PRINTREAS(MQRC_ADAPTER_DISC_LOAD_ERROR   )
    PRINTREAS(MQRC_CNO_ERROR                 )
    PRINTREAS(MQRC_CICS_WAIT_FAILED          )
    PRINTREAS(MQRC_DLH_ERROR                 )
    PRINTREAS(MQRC_HEADER_ERROR              )
    PRINTREAS(MQRC_SOURCE_LENGTH_ERROR       )
    PRINTREAS(MQRC_TARGET_LENGTH_ERROR       )
    PRINTREAS(MQRC_SOURCE_BUFFER_ERROR       )
    PRINTREAS(MQRC_TARGET_BUFFER_ERROR       )
    PRINTREAS(MQRC_IIH_ERROR                 )
    PRINTREAS(MQRC_PCF_ERROR                 )
    PRINTREAS(MQRC_DBCS_ERROR                )
    PRINTREAS(MQRC_OBJECT_NAME_ERROR         )
    PRINTREAS(MQRC_OBJECT_Q_MGR_NAME_ERROR   )
    PRINTREAS(MQRC_RECS_PRESENT_ERROR        )
    PRINTREAS(MQRC_OBJECT_RECORDS_ERROR      )
    PRINTREAS(MQRC_RESPONSE_RECORDS_ERROR    )
    PRINTREAS(MQRC_ASID_MISMATCH             )
    PRINTREAS(MQRC_PMO_RECORD_FLAGS_ERROR    )
    PRINTREAS(MQRC_PUT_MSG_RECORDS_ERROR     )
    PRINTREAS(MQRC_CONN_ID_IN_USE            )
    PRINTREAS(MQRC_Q_MGR_QUIESCING           )
    PRINTREAS(MQRC_Q_MGR_STOPPING            )
    PRINTREAS(MQRC_DUPLICATE_RECOV_COORD     )
    PRINTREAS(MQRC_PMO_ERROR                 )
    PRINTREAS(MQRC_API_EXIT_NOT_FOUND        )
    PRINTREAS(MQRC_API_EXIT_LOAD_ERROR       )
    PRINTREAS(MQRC_REMOTE_Q_NAME_ERROR       )
    PRINTREAS(MQRC_INCONSISTENT_PERSISTENCE  )
    PRINTREAS(MQRC_GMO_ERROR                 )
    PRINTREAS(MQRC_CICS_BRIDGE_RESTRICTION   )
    PRINTREAS(MQRC_STOPPED_BY_CLUSTER_EXIT   )
    PRINTREAS(MQRC_CLUSTER_RESOLUTION_ERROR  )
    PRINTREAS(MQRC_CONVERTED_STRING_TOO_BIG  )
    PRINTREAS(MQRC_TMC_ERROR                 )
    PRINTREAS(MQRC_STORAGE_MEDIUM_FULL       )
    PRINTREAS(MQRC_PAGESET_ERROR             )
    PRINTREAS(MQRC_NAME_NOT_VALID_FOR_TYPE   )
    PRINTREAS(MQRC_UNEXPECTED_ERROR          )
    PRINTREAS(MQRC_UNKNOWN_XMIT_Q            )
    PRINTREAS(MQRC_UNKNOWN_DEF_XMIT_Q        )
    PRINTREAS(MQRC_DEF_XMIT_Q_TYPE_ERROR     )
    PRINTREAS(MQRC_DEF_XMIT_Q_USAGE_ERROR    )
    PRINTREAS(MQRC_NAME_IN_USE               )
    PRINTREAS(MQRC_CONNECTION_QUIESCING      )
    PRINTREAS(MQRC_CONNECTION_STOPPING       )
    PRINTREAS(MQRC_ADAPTER_NOT_AVAILABLE     )
    PRINTREAS(MQRC_MSG_ID_ERROR              )
    PRINTREAS(MQRC_CORREL_ID_ERROR           )
    PRINTREAS(MQRC_FILE_SYSTEM_ERROR         )
    PRINTREAS(MQRC_NO_MSG_LOCKED             )
    PRINTREAS(MQRC_SOAP_DOTNET_ERROR         )
    PRINTREAS(MQRC_SOAP_AXIS_ERROR           )
    PRINTREAS(MQRC_SOAP_URL_ERROR            )
    PRINTREAS(MQRC_FILE_NOT_AUDITED          )
    PRINTREAS(MQRC_CONNECTION_NOT_AUTHORIZED )
    PRINTREAS(MQRC_MSG_TOO_BIG_FOR_CHANNEL   )
    PRINTREAS(MQRC_CALL_IN_PROGRESS          )
    PRINTREAS(MQRC_RMH_ERROR                 )
    PRINTREAS(MQRC_Q_MGR_ACTIVE              )
    PRINTREAS(MQRC_Q_MGR_NOT_ACTIVE          )
    PRINTREAS(MQRC_Q_DEPTH_HIGH              )
    PRINTREAS(MQRC_Q_DEPTH_LOW               )
    PRINTREAS(MQRC_Q_SERVICE_INTERVAL_HIGH   )
    PRINTREAS(MQRC_Q_SERVICE_INTERVAL_OK     )
    PRINTREAS(MQRC_RFH_HEADER_FIELD_ERROR    )
    PRINTREAS(MQRC_RAS_PROPERTY_ERROR        )
    PRINTREAS(MQRC_UNIT_OF_WORK_NOT_STARTED  )
    PRINTREAS(MQRC_CHANNEL_AUTO_DEF_OK       )
    PRINTREAS(MQRC_CHANNEL_AUTO_DEF_ERROR    )
    PRINTREAS(MQRC_CFH_ERROR                 )
    PRINTREAS(MQRC_CFIL_ERROR                )
    PRINTREAS(MQRC_CFIN_ERROR                )
    PRINTREAS(MQRC_CFSL_ERROR                )
    PRINTREAS(MQRC_CFST_ERROR                )
    PRINTREAS(MQRC_INCOMPLETE_GROUP          )
    PRINTREAS(MQRC_INCOMPLETE_MSG            )
    PRINTREAS(MQRC_INCONSISTENT_CCSIDS       )
    PRINTREAS(MQRC_INCONSISTENT_ENCODINGS    )
    PRINTREAS(MQRC_INCONSISTENT_UOW          )
    PRINTREAS(MQRC_INVALID_MSG_UNDER_CURSOR  )
    PRINTREAS(MQRC_MATCH_OPTIONS_ERROR       )
    PRINTREAS(MQRC_MDE_ERROR                 )
    PRINTREAS(MQRC_MSG_FLAGS_ERROR           )
    PRINTREAS(MQRC_MSG_SEQ_NUMBER_ERROR      )
    PRINTREAS(MQRC_OFFSET_ERROR              )
    PRINTREAS(MQRC_ORIGINAL_LENGTH_ERROR     )
    PRINTREAS(MQRC_SEGMENT_LENGTH_ZERO       )
    PRINTREAS(MQRC_UOW_NOT_AVAILABLE         )
    PRINTREAS(MQRC_WRONG_GMO_VERSION         )
    PRINTREAS(MQRC_WRONG_MD_VERSION          )
    PRINTREAS(MQRC_GROUP_ID_ERROR            )
    PRINTREAS(MQRC_INCONSISTENT_BROWSE       )
    PRINTREAS(MQRC_XQH_ERROR                 )
    PRINTREAS(MQRC_SRC_ENV_ERROR             )
    PRINTREAS(MQRC_SRC_NAME_ERROR            )
    PRINTREAS(MQRC_DEST_ENV_ERROR            )
    PRINTREAS(MQRC_DEST_NAME_ERROR           )
    PRINTREAS(MQRC_TM_ERROR                  )
    PRINTREAS(MQRC_CLUSTER_EXIT_ERROR        )
    PRINTREAS(MQRC_CLUSTER_EXIT_LOAD_ERROR   )
    PRINTREAS(MQRC_CLUSTER_PUT_INHIBITED     )
    PRINTREAS(MQRC_CLUSTER_RESOURCE_ERROR    )
    PRINTREAS(MQRC_NO_DESTINATIONS_AVAILABLE )
    PRINTREAS(MQRC_CONN_TAG_IN_USE           )
    PRINTREAS(MQRC_PARTIALLY_CONVERTED       )
    PRINTREAS(MQRC_CONNECTION_ERROR          )
    PRINTREAS(MQRC_OPTION_ENVIRONMENT_ERROR  )
    PRINTREAS(MQRC_CD_ERROR                  )
    PRINTREAS(MQRC_CLIENT_CONN_ERROR         )
    PRINTREAS(MQRC_CHANNEL_STOPPED_BY_USER   )
    PRINTREAS(MQRC_HCONFIG_ERROR             )
    PRINTREAS(MQRC_FUNCTION_ERROR            )
    PRINTREAS(MQRC_CHANNEL_STARTED           )
    PRINTREAS(MQRC_CHANNEL_STOPPED           )
    PRINTREAS(MQRC_CHANNEL_CONV_ERROR        )
    PRINTREAS(MQRC_SERVICE_NOT_AVAILABLE     )
    PRINTREAS(MQRC_INITIALIZATION_FAILED     )
    PRINTREAS(MQRC_TERMINATION_FAILED        )
    PRINTREAS(MQRC_UNKNOWN_Q_NAME            )
    PRINTREAS(MQRC_SERVICE_ERROR             )
    PRINTREAS(MQRC_Q_ALREADY_EXISTS          )
    PRINTREAS(MQRC_USER_ID_NOT_AVAILABLE     )
    PRINTREAS(MQRC_UNKNOWN_ENTITY            )
    PRINTREAS(MQRC_UNKNOWN_AUTH_ENTITY       )
    PRINTREAS(MQRC_UNKNOWN_REF_OBJECT        )
    PRINTREAS(MQRC_CHANNEL_ACTIVATED         )
    PRINTREAS(MQRC_CHANNEL_NOT_ACTIVATED     )
    PRINTREAS(MQRC_UOW_CANCELED              )
    PRINTREAS(MQRC_FUNCTION_NOT_SUPPORTED    )
    PRINTREAS(MQRC_SELECTOR_TYPE_ERROR       )
    PRINTREAS(MQRC_COMMAND_TYPE_ERROR        )
    PRINTREAS(MQRC_MULTIPLE_INSTANCE_ERROR   )
    PRINTREAS(MQRC_SYSTEM_ITEM_NOT_ALTERABLE )
    PRINTREAS(MQRC_BAG_CONVERSION_ERROR      )
    PRINTREAS(MQRC_SELECTOR_OUT_OF_RANGE     )
    PRINTREAS(MQRC_SELECTOR_NOT_UNIQUE       )
    PRINTREAS(MQRC_INDEX_NOT_PRESENT         )
    PRINTREAS(MQRC_STRING_ERROR              )
    PRINTREAS(MQRC_ENCODING_NOT_SUPPORTED    )
    PRINTREAS(MQRC_SELECTOR_NOT_PRESENT      )
    PRINTREAS(MQRC_OUT_SELECTOR_ERROR        )
    PRINTREAS(MQRC_STRING_TRUNCATED          )
    PRINTREAS(MQRC_SELECTOR_WRONG_TYPE       )
    PRINTREAS(MQRC_INCONSISTENT_ITEM_TYPE    )
    PRINTREAS(MQRC_INDEX_ERROR               )
    PRINTREAS(MQRC_SYSTEM_BAG_NOT_ALTERABLE  )
    PRINTREAS(MQRC_ITEM_COUNT_ERROR          )
    PRINTREAS(MQRC_FORMAT_NOT_SUPPORTED      )
    PRINTREAS(MQRC_SELECTOR_NOT_SUPPORTED    )
    PRINTREAS(MQRC_ITEM_VALUE_ERROR          )
    PRINTREAS(MQRC_HBAG_ERROR                )
    PRINTREAS(MQRC_PARAMETER_MISSING         )
    PRINTREAS(MQRC_CMD_SERVER_NOT_AVAILABLE  )
    PRINTREAS(MQRC_STRING_LENGTH_ERROR       )
    PRINTREAS(MQRC_INQUIRY_COMMAND_ERROR     )
    PRINTREAS(MQRC_NESTED_BAG_NOT_SUPPORTED  )
    PRINTREAS(MQRC_BAG_WRONG_TYPE            )
    PRINTREAS(MQRC_ITEM_TYPE_ERROR           )
    PRINTREAS(MQRC_SYSTEM_BAG_NOT_DELETABLE  )
    PRINTREAS(MQRC_SYSTEM_ITEM_NOT_DELETABLE )
    PRINTREAS(MQRC_CODED_CHAR_SET_ID_ERROR   )
    PRINTREAS(MQRC_MSG_TOKEN_ERROR           )
    PRINTREAS(MQRC_MISSING_WIH               )
    PRINTREAS(MQRC_WIH_ERROR                 )
    PRINTREAS(MQRC_RFH_ERROR                 )
    PRINTREAS(MQRC_RFH_STRING_ERROR          )
    PRINTREAS(MQRC_RFH_COMMAND_ERROR         )
    PRINTREAS(MQRC_RFH_PARM_ERROR            )
    PRINTREAS(MQRC_RFH_DUPLICATE_PARM        )
    PRINTREAS(MQRC_RFH_PARM_MISSING          )
    PRINTREAS(MQRC_CHAR_CONVERSION_ERROR     )
    PRINTREAS(MQRC_UCS2_CONVERSION_ERROR     )
    PRINTREAS(MQRC_DB2_NOT_AVAILABLE         )
    PRINTREAS(MQRC_OBJECT_NOT_UNIQUE         )
    PRINTREAS(MQRC_CONN_TAG_NOT_RELEASED     )
    PRINTREAS(MQRC_CF_NOT_AVAILABLE          )
    PRINTREAS(MQRC_CF_STRUC_IN_USE           )
    PRINTREAS(MQRC_CF_STRUC_LIST_HDR_IN_USE  )
    PRINTREAS(MQRC_CF_STRUC_AUTH_FAILED      )
    PRINTREAS(MQRC_CF_STRUC_ERROR            )
    PRINTREAS(MQRC_CONN_TAG_NOT_USABLE       )
    PRINTREAS(MQRC_GLOBAL_UOW_CONFLICT       )
    PRINTREAS(MQRC_LOCAL_UOW_CONFLICT        )
    PRINTREAS(MQRC_HANDLE_IN_USE_FOR_UOW     )
    PRINTREAS(MQRC_UOW_ENLISTMENT_ERROR      )
    PRINTREAS(MQRC_UOW_MIX_NOT_SUPPORTED     )
    PRINTREAS(MQRC_WXP_ERROR                 )
    PRINTREAS(MQRC_CURRENT_RECORD_ERROR      )
    PRINTREAS(MQRC_NEXT_OFFSET_ERROR         )
    PRINTREAS(MQRC_NO_RECORD_AVAILABLE       )
    PRINTREAS(MQRC_OBJECT_LEVEL_INCOMPATIBLE )
    PRINTREAS(MQRC_NEXT_RECORD_ERROR         )
    PRINTREAS(MQRC_BACKOUT_THRESHOLD_REACHED )
    PRINTREAS(MQRC_MSG_NOT_MATCHED           )
    PRINTREAS(MQRC_JMS_FORMAT_ERROR          )
    PRINTREAS(MQRC_SEGMENTS_NOT_SUPPORTED    )
    PRINTREAS(MQRC_WRONG_CF_LEVEL            )
    PRINTREAS(MQRC_CONFIG_CREATE_OBJECT      )
    PRINTREAS(MQRC_CONFIG_CHANGE_OBJECT      )
    PRINTREAS(MQRC_CONFIG_DELETE_OBJECT      )
    PRINTREAS(MQRC_CONFIG_REFRESH_OBJECT     )
    PRINTREAS(MQRC_CHANNEL_SSL_ERROR         )
    PRINTREAS(MQRC_CF_STRUC_FAILED           )
    PRINTREAS(MQRC_API_EXIT_ERROR            )
    PRINTREAS(MQRC_API_EXIT_INIT_ERROR       )
    PRINTREAS(MQRC_API_EXIT_TERM_ERROR       )
    PRINTREAS(MQRC_EXIT_REASON_ERROR         )
    PRINTREAS(MQRC_RESERVED_VALUE_ERROR      )
    PRINTREAS(MQRC_NO_DATA_AVAILABLE         )
    PRINTREAS(MQRC_SCO_ERROR                 )
    PRINTREAS(MQRC_KEY_REPOSITORY_ERROR      )
    PRINTREAS(MQRC_CRYPTO_HARDWARE_ERROR     )
    PRINTREAS(MQRC_AUTH_INFO_REC_COUNT_ERROR )
    PRINTREAS(MQRC_AUTH_INFO_REC_ERROR       )
    PRINTREAS(MQRC_AIR_ERROR                 )
    PRINTREAS(MQRC_AUTH_INFO_TYPE_ERROR      )
    PRINTREAS(MQRC_AUTH_INFO_CONN_NAME_ERROR )
    PRINTREAS(MQRC_LDAP_USER_NAME_ERROR      )
    PRINTREAS(MQRC_LDAP_USER_NAME_LENGTH_ERR )
    PRINTREAS(MQRC_LDAP_PASSWORD_ERROR       )
    PRINTREAS(MQRC_SSL_ALREADY_INITIALIZED   )
    PRINTREAS(MQRC_SSL_CONFIG_ERROR          )
    PRINTREAS(MQRC_SSL_INITIALIZATION_ERROR  )
    PRINTREAS(MQRC_Q_INDEX_TYPE_ERROR        )
    PRINTREAS(MQRC_CFBS_ERROR                )
    PRINTREAS(MQRC_SSL_NOT_ALLOWED           )
    PRINTREAS(MQRC_JSSE_ERROR                )
    PRINTREAS(MQRC_SSL_PEER_NAME_MISMATCH    )
    PRINTREAS(MQRC_SSL_PEER_NAME_ERROR       )
    PRINTREAS(MQRC_UNSUPPORTED_CIPHER_SUITE  )
    PRINTREAS(MQRC_SSL_CERTIFICATE_REVOKED   )
    PRINTREAS(MQRC_SSL_CERT_STORE_ERROR      )
    PRINTREAS(MQRC_CLIENT_EXIT_LOAD_ERROR    )
    PRINTREAS(MQRC_CLIENT_EXIT_ERROR         )
    PRINTREAS(MQRC_SSL_KEY_RESET_ERROR       )
    PRINTREAS(MQRC_UNKNOWN_COMPONENT_NAME    )
    PRINTREAS(MQRC_LOGGER_STATUS             )
    PRINTREAS(MQRC_COMMAND_MQSC              )
    PRINTREAS(MQRC_COMMAND_PCF               )
    PRINTREAS(MQRC_CFIF_ERROR                )
    PRINTREAS(MQRC_CFSF_ERROR                )
    PRINTREAS(MQRC_CFGR_ERROR                )
    PRINTREAS(MQRC_MSG_NOT_ALLOWED_IN_GROUP  )
    PRINTREAS(MQRC_FILTER_OPERATOR_ERROR     )
    PRINTREAS(MQRC_NESTED_SELECTOR_ERROR     )
    PRINTREAS(MQRC_EPH_ERROR                 )
    PRINTREAS(MQRC_RFH_FORMAT_ERROR          )
    PRINTREAS(MQRC_CFBF_ERROR                )
    PRINTREAS(MQRC_CLIENT_CHANNEL_CONFLICT   )
    PRINTREAS(MQRC_REOPEN_EXCL_INPUT_ERROR   )
    PRINTREAS(MQRC_REOPEN_INQUIRE_ERROR      )
    PRINTREAS(MQRC_REOPEN_SAVED_CONTEXT_ERR  )
    PRINTREAS(MQRC_REOPEN_TEMPORARY_Q_ERROR  )
    PRINTREAS(MQRC_ATTRIBUTE_LOCKED          )
    PRINTREAS(MQRC_CURSOR_NOT_VALID          )
    PRINTREAS(MQRC_ENCODING_ERROR            )
    PRINTREAS(MQRC_STRUC_ID_ERROR            )
    PRINTREAS(MQRC_NULL_POINTER              )
    PRINTREAS(MQRC_NO_CONNECTION_REFERENCE   )
    PRINTREAS(MQRC_NO_BUFFER                 )
    PRINTREAS(MQRC_BINARY_DATA_LENGTH_ERROR  )
    PRINTREAS(MQRC_BUFFER_NOT_AUTOMATIC      )
    PRINTREAS(MQRC_INSUFFICIENT_BUFFER       )
    PRINTREAS(MQRC_INSUFFICIENT_DATA         )
    PRINTREAS(MQRC_DATA_TRUNCATED            )
    PRINTREAS(MQRC_ZERO_LENGTH               )
    PRINTREAS(MQRC_NEGATIVE_LENGTH           )
    PRINTREAS(MQRC_NEGATIVE_OFFSET           )
    PRINTREAS(MQRC_INCONSISTENT_FORMAT       )
    PRINTREAS(MQRC_INCONSISTENT_OBJECT_STATE )
    PRINTREAS(MQRC_CONTEXT_OBJECT_NOT_VALID  )
    PRINTREAS(MQRC_CONTEXT_OPEN_ERROR        )
    PRINTREAS(MQRC_STRUC_LENGTH_ERROR        )
    PRINTREAS(MQRC_NOT_CONNECTED             )
    PRINTREAS(MQRC_NOT_OPEN                  )
    PRINTREAS(MQRC_DISTRIBUTION_LIST_EMPTY   )
    PRINTREAS(MQRC_INCONSISTENT_OPEN_OPTIONS )
    PRINTREAS(MQRC_WRONG_VERSION             )
    PRINTREAS(MQRC_REFERENCE_ERROR           )
    default:
      printf("It's an unknown reason, %ld\n",
              reason);
      break;
  }
}
